@@ -103,7 +103,8 @@ def write_default_ansible_cfg(work_dir,
                     datetime.now().strftime("%Y-%m-%dT%H:%M:%S"))
         os.rename(log_path, new_path)
 
-    config.set('defaults', 'forks', str(multiprocessing.cpu_count() * 10))
+    config.set('defaults', 'forks', str(min(
+        multiprocessing.cpu_count() * 4, 100)))
     config.set('defaults', 'timeout', '30')
     config.set('defaults', 'gather_timeout', '30')
 
@@ -339,8 +340,8 @@ class AnsiblePlaybookAction(base.TripleOAction):
         python_version = sys.version_info.major
         ansible_playbook_cmd = "ansible-playbook-{}".format(python_version)
 
-        if 0 < self.verbosity < 6:
-            verbosity_option = '-' + ('v' * self.verbosity)
+        if 1 < self.verbosity < 6:
+            verbosity_option = '-' + ('v' * (self.verbosity - 1))
             command = [ansible_playbook_cmd, verbosity_option,
                        self.playbook]
         else:
