@@ -889,8 +889,7 @@ class TestConfig(base.TestCase):
         self.config = ooo_config.Config(heat)
         stack = mock.Mock()
         server_roles = dict(Controller='controller')
-        mock_get_network_config_data.return_value = dict(
-            Controller='56f27b7a-7bb8-40bc-bfdb-a46f7f806b88')
+        mock_get_network_config_data.return_value = dict(Controller='config')
         config_dir = '/tmp/tht'
         self.config.render_network_config(stack, config_dir, server_roles)
 
@@ -908,16 +907,55 @@ class TestConfig(base.TestCase):
         self.config = ooo_config.Config(heat)
         stack = mock.Mock()
         server_roles = dict(node1='Controller')
-        mock_get_network_config_data.return_value = dict(
-            node1='56f27b7a-7bb8-40bc-bfdb-a46f7f806b88',
-            node2='56f27b7a-7bb8-40bc-bfdb-a46f7f806b88')
+        mock_get_network_config_data.return_value = dict(node1='config',
+                                                         node2='config')
         config_dir = '/tmp/tht'
         self.config.render_network_config(stack, config_dir, server_roles)
-        self.assertEqual(2, mock_open.call_count)
-        self.assertEqual('/tmp/tht/Controller/node1/NetworkConfig',
-                         mock_open.call_args_list[0][0][0])
+        self.assertEqual(1, mock_open.call_count)
         self.assertEqual('/tmp/tht/Controller/NetworkConfig',
-                         mock_open.call_args_list[1][0][0])
+                         mock_open.call_args_list[0][0][0])
+
+    @patch('tripleo_common.utils.config.Config.get_network_config_data')
+    @patch('tripleo_common.utils.config.Config.get_role_network_config_data')
+    def test_render_role_network_config_empty_dict(
+            self, mock_get_role_network_config_data,
+            mock_get_network_config_data):
+        heat = mock.MagicMock()
+        heat.stacks.get.return_value = fakes.create_tht_stack()
+        config_mock = mock.MagicMock()
+        config_mock.config = {}
+        heat.software_configs.get.return_value = config_mock
+
+        self.config = ooo_config.Config(heat)
+        stack = mock.Mock()
+        mock_get_role_network_config_data.return_value = dict(
+            Controller='config')
+        config_dir = '/tmp/tht'
+        self.config.render_network_config(stack, config_dir, mock.ANY)
+        mock_get_network_config_data.assert_not_called()
+
+    @patch.object(ooo_config.Config, '_open_file')
+    @patch('tripleo_common.utils.config.Config.get_network_config_data')
+    @patch('tripleo_common.utils.config.Config.get_role_network_config_data')
+    def test_render_role_network_config(self,
+                                        mock_get_role_network_config_data,
+                                        mock_get_network_config_data,
+                                        mock_open):
+        heat = mock.MagicMock()
+        heat.stacks.get.return_value = fakes.create_tht_stack()
+        config_mock = mock.MagicMock()
+        config_mock.config = 'some config'
+        heat.software_configs.get.return_value = config_mock
+        self.config = ooo_config.Config(heat)
+        stack = mock.Mock()
+        mock_get_role_network_config_data.return_value = dict(
+            Controller='config')
+        config_dir = '/tmp/tht'
+        self.config.render_network_config(stack, config_dir, mock.ANY)
+        self.assertEqual(1, mock_open.call_count)
+        self.assertEqual('/tmp/tht/Controller/NetworkConfig',
+                         mock_open.call_args_list[0][0][0])
+        mock_get_network_config_data.assert_not_called()
 
 
 class OvercloudConfigTest(base.TestCase):
